// Copyright (c) 2023, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

import 'dart:js_interop';

import 'webgl1.dart';

@JS('WEBGL_blend_equation_advanced_coherent')
@staticInterop
class WEBGL_blend_equation_advanced_coherent {
  external static GLenum get MULTIPLY;
  external static GLenum get SCREEN;
  external static GLenum get OVERLAY;
  external static GLenum get DARKEN;
  external static GLenum get LIGHTEN;
  external static GLenum get COLORDODGE;
  external static GLenum get COLORBURN;
  external static GLenum get HARDLIGHT;
  external static GLenum get SOFTLIGHT;
  external static GLenum get DIFFERENCE;
  external static GLenum get EXCLUSION;
  external static GLenum get HSL_HUE;
  external static GLenum get HSL_SATURATION;
  external static GLenum get HSL_COLOR;
  external static GLenum get HSL_LUMINOSITY;
}
